OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontaktid",
    "Address book name" : "Aadressiraamatu nimi",
    "Import" : "Impordi",
    "No contacts in here" : "Ühtegi kontakti pole",
    "Name" : "Nimi",
    "Organization" : "Organisatsioon",
    "Title" : "Pealkiri",
    "Add field ..." : "Lisa väli ...",
    "No search result for {query}" : "Otsingutulemused sõnadele {query}",
    "Postal code" : "Postiindeks",
    "City" : "Linn",
    "State or province" : "Maakond",
    "Country" : "Riik",
    "Address" : "Aadress",
    "(new group)" : "(uus grupps)",
    "Last name" : "Perekonnanimi",
    "First name" : "Eesnimi",
    "Additional names" : "Lisanimed",
    "All contacts" : "Kõik kontaktid",
    "Not grouped" : "Pole grupeeritud",
    "New contact" : "Uus kontakt",
    "{addressbook} shared by {owner}" : "{owner} jagas aadressiraamatut {addressbook}",
    "Nickname" : "Hüüdnimi",
    "Notes" : "Märkmed",
    "Website" : "Veebileht",
    "Home" : "Kodu",
    "Work" : "Töö",
    "Other" : "Muu",
    "Groups" : "Grupid",
    "Birthday" : "Sünnipäev",
    "Email" : "E-post",
    "Instant messaging" : "Kiirõnumid",
    "Phone" : "Telefon",
    "Mobile" : "Mobiil",
    "Fax" : "Faks",
    "Fax home" : "Faks kodus",
    "Fax work" : "Faks tööl",
    "Pager" : "Piipar",
    "Voice" : "Hääl",
    "Settings" : "Seaded"
},
"nplurals=2; plural=(n != 1);");
